using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Dialog box for CurveRenderer settings.
	/// </summary>
	public class CurveRendererSettings : System.Windows.Forms.Form
	{

		/// <summary> Renderer object. </summary>
		private CurveRenderer renderer;

		#region variables for saving of the original state

		private bool orig_showXGrid;
		private bool orig_showYGrid;
		private bool orig_showXAxesLegend;
		private bool orig_showYAxesLegend;
		private int orig_y_segment_count;
		private int orig_x_segment_count;
		private bool orig_showGraphMarks;
		private int orig_graphMarkSize;
		private int orig_graphMarkLineWidth;
		private int orig_graphLineWidth;
		private Color orig_graphLineColor;
		private Color orig_marksLineColor;
		private int orig_decPlaceCountX;
		private int orig_decPlaceCountY;
		private Font orig_axisFont;
		private Color orig_axesLineColor;
		private Color orig_axesTextColor;
		private bool orig_showRectangle;
		private bool orig_showIndexes;
		private Font orig_indexFont;
		private bool orig_showGraphLine;
		private CurveRenderer.Interpolation orig_interpolation;
		private bool orig_allowHighlighting;
		private int orig_hMarksSize;
		private int orig_hMarksLineWidth;
		private Color orig_hMarksColor;
		private Font orig_hMarksFont;

		#endregion

		#region Designer generated fields

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.CheckBox checkBox1;
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.Button button2;
		private System.Windows.Forms.CheckBox checkBox2;
		private System.Windows.Forms.CheckBox checkBox4;
		private System.Windows.Forms.CheckBox checkBox3;
		private System.Windows.Forms.NumericUpDown numericUpDown1;
		private System.Windows.Forms.GroupBox groupBox3;
		private System.Windows.Forms.CheckBox checkBox5;
		private System.Windows.Forms.NumericUpDown numericUpDown2;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.NumericUpDown numericUpDown3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.NumericUpDown numericUpDown4;
		private System.Windows.Forms.ColorDialog colorDialog1;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.Button button3;
		private System.Windows.Forms.Button button4;
		private System.Windows.Forms.ColorDialog colorDialog2;
		private System.Windows.Forms.GroupBox groupBox4;
		private System.Windows.Forms.NumericUpDown NUD_xSegmentCount;
		private System.Windows.Forms.GroupBox groupBox5;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.GroupBox groupBox6;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.NumericUpDown NUD_decPlaceCountX;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.NumericUpDown NUD_decPlaceCountY;
		private System.Windows.Forms.Label label9;
		private System.Windows.Forms.Button Bt_apply;
		private System.Windows.Forms.FontDialog FD_Axes;
		private System.Windows.Forms.Button Bt_font;
		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.TabPage tabPage2;
		private System.Windows.Forms.Label label10;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.ColorDialog CD_AxesLine;
		private System.Windows.Forms.ColorDialog CD_AxesText;
		private System.Windows.Forms.Button BT_AxesLineColor;
		private System.Windows.Forms.Button BT_AxesTextColor;
		private System.Windows.Forms.CheckBox ChB_showIndexes;
		private System.Windows.Forms.Button BT_FontIndexes;
		private System.Windows.Forms.FontDialog FD_Indexes;
		private System.Windows.Forms.CheckBox ChB_ShowLine;
		private System.Windows.Forms.RadioButton RB_PolyLine;
		private System.Windows.Forms.RadioButton RB_Bezier;
		private System.Windows.Forms.Label label12;
		private System.Windows.Forms.Button Bt_restoreDefault;
		private System.Windows.Forms.TabPage tabPage3;
		private System.Windows.Forms.CheckBox Chb_allowHighligting;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.NumericUpDown NUD_sizeHMarks;
		private System.Windows.Forms.NumericUpDown NUD_sizeHMarksLineWidth;
		private System.Windows.Forms.Button Bt_HMarksColor;
		private System.Windows.Forms.Label label13;
		private System.Windows.Forms.Label label14;
		private System.Windows.Forms.Label label15;
		private System.Windows.Forms.Button Bt_HMarksFont;
		private System.Windows.Forms.ColorDialog CD_hMarks;
		private System.Windows.Forms.FontDialog FD_hMarks;
		private System.Windows.Forms.CheckBox ChB_showRectangle;

		#endregion


		/// <summary>
		/// Create dialog box.
		/// </summary>
		/// <param name="rendererPanel">CurveRenderer panel.</param>
		public CurveRendererSettings(CurveRenderer renderer)
		{
			this.renderer = renderer;
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
			SetControlValues();
		} // CurveRendererSettings()


		#region Auxiliary methods for renderer settings

		/// <summary>
		/// Set control values depending on current renderer settings.
		/// </summary>
		private void SetControlValues()
		{
			this.checkBox1.Checked = this.renderer.showXGrid;
			this.checkBox2.Checked = this.renderer.showYGrid;
			this.checkBox3.Checked = this.renderer.showXAxesLegend;
			this.checkBox4.Checked = this.renderer.showYAxesLegend;
			this.NUD_xSegmentCount.Value = this.renderer.x_segment_count;
			this.numericUpDown1.Value = this.renderer.y_segment_count;
			this.checkBox5.Checked = this.renderer.showGraphMarks;
			this.numericUpDown2.Enabled = this.checkBox5.Checked;
			this.numericUpDown4.Enabled = this.checkBox5.Checked;
			this.label2.Enabled = this.checkBox5.Checked;
			this.label4.Enabled = this.checkBox5.Checked;
			this.label6.Enabled = this.checkBox5.Checked;
			this.button4.Enabled = this.checkBox5.Checked;
			this.numericUpDown2.Value = (int) this.renderer.graph_mark_size;
			this.numericUpDown4.Value = this.renderer.graphMarkLineWidth;
			this.numericUpDown3.Value = this.renderer.graphLineWidth;
			this.colorDialog1.Color = this.renderer.graphLineColor;
			this.button3.BackColor = this.colorDialog1.Color;
			this.colorDialog2.Color = this.renderer.marksLineColor;
			this.button4.BackColor = this.colorDialog2.Color;
			this.NUD_decPlaceCountX.Value = this.renderer.decPlaceCountX;
			this.NUD_decPlaceCountY.Value = this.renderer.decPlaceCountY;

			this.CD_AxesLine.Color = this.renderer.axesLineColor;
			this.BT_AxesLineColor.BackColor = this.CD_AxesLine.Color;
			this.CD_AxesText.Color = this.renderer.axesTextColor;
			this.BT_AxesTextColor.BackColor = this.CD_AxesText.Color;

			this.ChB_showRectangle.Checked = this.renderer.showRectangle;
			this.ChB_showIndexes.Checked = this.renderer.showIndexes;

			this.FD_Axes.Font = this.renderer.axisFont;
			this.FD_Indexes.Font = this.renderer.indexFont;

			this.ChB_ShowLine.Checked = this.renderer.showGraphLine;

			if (this.renderer.interpolation == CurveRenderer.Interpolation.PolyLine)
				this.RB_PolyLine.Checked = true;
			else
				this.RB_Bezier.Checked = true;

			this.Chb_allowHighligting.Checked = this.renderer.allowHighlighting;
			this.NUD_sizeHMarks.Value = renderer.hMarksSize;
			this.NUD_sizeHMarksLineWidth.Value = renderer.hMarksLineWidth;
			this.FD_hMarks.Font = renderer.hMarksFont;
			this.CD_hMarks.Color = renderer.hMarksColor;
			this.Bt_HMarksColor.BackColor = this.CD_hMarks.Color;

			SaveOrigState();
			this.SetAccessabilityMarks();
			this.SetAccessabilityLine();
			this.SetAccessabilityHighlighting();
		} // SetControlValues()

		/// <summary>
		/// Saves changes into renderer settings.
		/// </summary>
		private void ApplyChanges()
		{
			this.renderer.showXGrid = this.checkBox1.Checked;
			this.renderer.showYGrid = this.checkBox2.Checked;
			this.renderer.showXAxesLegend = this.checkBox3.Checked;
			this.renderer.showYAxesLegend = this.checkBox4.Checked;
			this.renderer.x_segment_count = (int) this.NUD_xSegmentCount.Value;
			this.renderer.y_segment_count = (int) this.numericUpDown1.Value;
			this.renderer.showGraphMarks = this.checkBox5.Checked;
			this.renderer.graph_mark_size = (int) this.numericUpDown2.Value;
			this.renderer.graphLineWidth = (int) this.numericUpDown3.Value;
			this.renderer.graphMarkLineWidth = (int) this.numericUpDown4.Value;
			this.renderer.graphLineColor = this.colorDialog1.Color;
			this.renderer.marksLineColor = this.colorDialog2.Color;
			this.renderer.decPlaceCountX = (int) this.NUD_decPlaceCountX.Value;
			this.renderer.decPlaceCountY = (int) this.NUD_decPlaceCountY.Value;
			this.renderer.axisFont = this.FD_Axes.Font;
			this.renderer.axesLineColor = this.CD_AxesLine.Color;
			this.renderer.axesTextColor = this.CD_AxesText.Color;
			this.renderer.showRectangle = this.ChB_showRectangle.Checked;
			this.renderer.showIndexes = this.ChB_showIndexes.Checked;
			this.renderer.indexFont = this.FD_Indexes.Font;
			this.renderer.showGraphLine = this.ChB_ShowLine.Checked;

			if (this.RB_PolyLine.Checked)
				this.renderer.interpolation = CurveRenderer.Interpolation.PolyLine;
			else
				this.renderer.interpolation = CurveRenderer.Interpolation.Bezier;

			this.renderer.allowHighlighting = this.Chb_allowHighligting.Checked;
			this.renderer.hMarksSize = (int) this.NUD_sizeHMarks.Value;
			this.renderer.hMarksLineWidth = (int) this.NUD_sizeHMarksLineWidth.Value;
			this.renderer.hMarksFont = this.FD_hMarks.Font;
			this.renderer.hMarksColor = this.CD_hMarks.Color;

			this.renderer.panel.Refresh();
		} // ApplyChanges()

		/// <summary>
		/// Saves original state into temporary fields.
		/// </summary>
		private void SaveOrigState()
		{
			this.orig_showXGrid = this.renderer.showXGrid;
			this.orig_showYGrid = this.renderer.showYGrid;
			this.orig_showXAxesLegend = this.renderer.showXAxesLegend;
			this.orig_showYAxesLegend  = this.renderer.showYAxesLegend;
			this.orig_y_segment_count = this.renderer.y_segment_count;
			this.orig_x_segment_count  = this.renderer.x_segment_count;
			this.orig_showGraphMarks = this.renderer.showGraphMarks;
			this.orig_graphMarkSize = (int) this.renderer.graph_mark_size;
			this.orig_graphMarkLineWidth = this.renderer.graphMarkLineWidth;
			this.orig_graphLineWidth = this.renderer.graphLineWidth;
			this.orig_graphLineColor = this.renderer.graphLineColor;
			this.orig_marksLineColor = this.renderer.marksLineColor;
			this.orig_decPlaceCountX = this.renderer.decPlaceCountX;
			this.orig_decPlaceCountY = this.renderer.decPlaceCountY;
			this.orig_axisFont = this.renderer.axisFont;
			this.orig_axesLineColor = this.renderer.axesLineColor;
			this.orig_axesTextColor = this.renderer.axesTextColor;
			this.orig_showRectangle = this.renderer.showRectangle;
			this.orig_showIndexes = this.renderer.showIndexes;
			this.orig_indexFont = this.renderer.indexFont;
			this.orig_showGraphLine = this.renderer.showGraphLine;
			this.orig_interpolation = this.renderer.interpolation;
			this.orig_allowHighlighting = this.renderer.allowHighlighting;
			this.orig_hMarksSize = this.renderer.hMarksSize;
			this.orig_hMarksLineWidth = this.renderer.hMarksLineWidth;
			this.orig_hMarksFont = this.renderer.hMarksFont;
			this.orig_hMarksColor = this.renderer.hMarksColor;
		} // SaveOrigState()

		/// <summary>
		/// Discard changes, restore original state from temporary fields
		/// </summary>
		private void DiscardChanges()
		{
			this.renderer.showXGrid = this.orig_showXGrid;
			this.renderer.showYGrid = this.orig_showYGrid;
			this.renderer.showXAxesLegend = this.orig_showXAxesLegend;
			this.renderer.showYAxesLegend = this.orig_showYAxesLegend;
			this.renderer.y_segment_count = this.orig_y_segment_count;
			this.renderer.x_segment_count = this.orig_x_segment_count;
			this.renderer.showGraphMarks = this.orig_showGraphMarks;
			this.renderer.graph_mark_size = this.orig_graphMarkSize;
			this.renderer.graphMarkLineWidth = this.orig_graphMarkLineWidth;
			this.renderer.graphLineWidth = this.orig_graphLineWidth;
			this.renderer.graphLineColor = this.orig_graphLineColor;
			this.renderer.marksLineColor = this.orig_marksLineColor;
			this.renderer.decPlaceCountX = this.orig_decPlaceCountX;
			this.renderer.decPlaceCountY = this.orig_decPlaceCountY;
			this.renderer.axisFont = this.orig_axisFont;
			this.renderer.axesLineColor = this.orig_axesLineColor;
			this.renderer.axesTextColor = this.orig_axesTextColor;
			this.renderer.showRectangle = this.orig_showRectangle;
			this.renderer.showIndexes = this.orig_showIndexes;
			this.renderer.indexFont = this.orig_indexFont;
			this.renderer.showGraphLine = this.orig_showGraphLine;
			this.renderer.interpolation = this.orig_interpolation;
			this.renderer.allowHighlighting = this.orig_allowHighlighting;
			this.renderer.hMarksSize = this.orig_hMarksSize;
			this.renderer.hMarksLineWidth = this.orig_hMarksLineWidth;
			this.renderer.hMarksFont = this.orig_hMarksFont;
			this.renderer.hMarksColor = this.orig_hMarksColor;

			this.renderer.panel.Refresh();
		} // DiscardChanges()

		#endregion


		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.checkBox1 = new System.Windows.Forms.CheckBox();
			this.button1 = new System.Windows.Forms.Button();
			this.button2 = new System.Windows.Forms.Button();
			this.checkBox2 = new System.Windows.Forms.CheckBox();
			this.checkBox4 = new System.Windows.Forms.CheckBox();
			this.checkBox3 = new System.Windows.Forms.CheckBox();
			this.numericUpDown1 = new System.Windows.Forms.NumericUpDown();
			this.groupBox3 = new System.Windows.Forms.GroupBox();
			this.BT_FontIndexes = new System.Windows.Forms.Button();
			this.numericUpDown2 = new System.Windows.Forms.NumericUpDown();
			this.numericUpDown4 = new System.Windows.Forms.NumericUpDown();
			this.button4 = new System.Windows.Forms.Button();
			this.checkBox5 = new System.Windows.Forms.CheckBox();
			this.label2 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.label6 = new System.Windows.Forms.Label();
			this.ChB_showIndexes = new System.Windows.Forms.CheckBox();
			this.label3 = new System.Windows.Forms.Label();
			this.numericUpDown3 = new System.Windows.Forms.NumericUpDown();
			this.colorDialog1 = new System.Windows.Forms.ColorDialog();
			this.label5 = new System.Windows.Forms.Label();
			this.button3 = new System.Windows.Forms.Button();
			this.colorDialog2 = new System.Windows.Forms.ColorDialog();
			this.groupBox4 = new System.Windows.Forms.GroupBox();
			this.RB_PolyLine = new System.Windows.Forms.RadioButton();
			this.ChB_showRectangle = new System.Windows.Forms.CheckBox();
			this.ChB_ShowLine = new System.Windows.Forms.CheckBox();
			this.RB_Bezier = new System.Windows.Forms.RadioButton();
			this.label12 = new System.Windows.Forms.Label();
			this.NUD_xSegmentCount = new System.Windows.Forms.NumericUpDown();
			this.groupBox5 = new System.Windows.Forms.GroupBox();
			this.label7 = new System.Windows.Forms.Label();
			this.NUD_decPlaceCountX = new System.Windows.Forms.NumericUpDown();
			this.label1 = new System.Windows.Forms.Label();
			this.groupBox6 = new System.Windows.Forms.GroupBox();
			this.label8 = new System.Windows.Forms.Label();
			this.NUD_decPlaceCountY = new System.Windows.Forms.NumericUpDown();
			this.label9 = new System.Windows.Forms.Label();
			this.FD_Axes = new System.Windows.Forms.FontDialog();
			this.Bt_apply = new System.Windows.Forms.Button();
			this.Bt_font = new System.Windows.Forms.Button();
			this.tabControl1 = new System.Windows.Forms.TabControl();
			this.tabPage1 = new System.Windows.Forms.TabPage();
			this.BT_AxesLineColor = new System.Windows.Forms.Button();
			this.label10 = new System.Windows.Forms.Label();
			this.BT_AxesTextColor = new System.Windows.Forms.Button();
			this.label11 = new System.Windows.Forms.Label();
			this.tabPage2 = new System.Windows.Forms.TabPage();
			this.tabPage3 = new System.Windows.Forms.TabPage();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.Chb_allowHighligting = new System.Windows.Forms.CheckBox();
			this.CD_AxesLine = new System.Windows.Forms.ColorDialog();
			this.CD_AxesText = new System.Windows.Forms.ColorDialog();
			this.FD_Indexes = new System.Windows.Forms.FontDialog();
			this.Bt_restoreDefault = new System.Windows.Forms.Button();
			this.NUD_sizeHMarks = new System.Windows.Forms.NumericUpDown();
			this.NUD_sizeHMarksLineWidth = new System.Windows.Forms.NumericUpDown();
			this.Bt_HMarksColor = new System.Windows.Forms.Button();
			this.label13 = new System.Windows.Forms.Label();
			this.label14 = new System.Windows.Forms.Label();
			this.label15 = new System.Windows.Forms.Label();
			this.Bt_HMarksFont = new System.Windows.Forms.Button();
			this.CD_hMarks = new System.Windows.Forms.ColorDialog();
			this.FD_hMarks = new System.Windows.Forms.FontDialog();
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown1)).BeginInit();
			this.groupBox3.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown2)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown4)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown3)).BeginInit();
			this.groupBox4.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.NUD_xSegmentCount)).BeginInit();
			this.groupBox5.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.NUD_decPlaceCountX)).BeginInit();
			this.groupBox6.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.NUD_decPlaceCountY)).BeginInit();
			this.tabControl1.SuspendLayout();
			this.tabPage1.SuspendLayout();
			this.tabPage2.SuspendLayout();
			this.tabPage3.SuspendLayout();
			this.groupBox1.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.NUD_sizeHMarks)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.NUD_sizeHMarksLineWidth)).BeginInit();
			this.SuspendLayout();
			// 
			// checkBox1
			// 
			this.checkBox1.Location = new System.Drawing.Point(16, 48);
			this.checkBox1.Name = "checkBox1";
			this.checkBox1.Size = new System.Drawing.Size(80, 24);
			this.checkBox1.TabIndex = 1;
			this.checkBox1.Text = "Show grid";
			// 
			// button1
			// 
			this.button1.Location = new System.Drawing.Point(240, 248);
			this.button1.Name = "button1";
			this.button1.Size = new System.Drawing.Size(56, 23);
			this.button1.TabIndex = 1;
			this.button1.Text = "&OK";
			this.button1.Click += new System.EventHandler(this.button1_Click);
			// 
			// button2
			// 
			this.button2.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.button2.Location = new System.Drawing.Point(368, 248);
			this.button2.Name = "button2";
			this.button2.Size = new System.Drawing.Size(56, 23);
			this.button2.TabIndex = 3;
			this.button2.Text = "&Storno";
			this.button2.Click += new System.EventHandler(this.button2_Click);
			// 
			// checkBox2
			// 
			this.checkBox2.Location = new System.Drawing.Point(16, 48);
			this.checkBox2.Name = "checkBox2";
			this.checkBox2.Size = new System.Drawing.Size(80, 24);
			this.checkBox2.TabIndex = 1;
			this.checkBox2.Text = "Show grid";
			// 
			// checkBox4
			// 
			this.checkBox4.Location = new System.Drawing.Point(16, 24);
			this.checkBox4.Name = "checkBox4";
			this.checkBox4.Size = new System.Drawing.Size(96, 24);
			this.checkBox4.TabIndex = 0;
			this.checkBox4.Text = "Show labels";
			// 
			// checkBox3
			// 
			this.checkBox3.Location = new System.Drawing.Point(16, 24);
			this.checkBox3.Name = "checkBox3";
			this.checkBox3.Size = new System.Drawing.Size(96, 24);
			this.checkBox3.TabIndex = 0;
			this.checkBox3.Text = "Show labels";
			// 
			// numericUpDown1
			// 
			this.numericUpDown1.Location = new System.Drawing.Point(112, 80);
			this.numericUpDown1.Maximum = new System.Decimal(new int[] {
																		   1000,
																		   0,
																		   0,
																		   0});
			this.numericUpDown1.Minimum = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.numericUpDown1.Name = "numericUpDown1";
			this.numericUpDown1.Size = new System.Drawing.Size(48, 20);
			this.numericUpDown1.TabIndex = 2;
			this.numericUpDown1.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.numericUpDown1.Value = new System.Decimal(new int[] {
																		 1,
																		 0,
																		 0,
																		 0});
			// 
			// groupBox3
			// 
			this.groupBox3.Controls.Add(this.BT_FontIndexes);
			this.groupBox3.Controls.Add(this.numericUpDown2);
			this.groupBox3.Controls.Add(this.numericUpDown4);
			this.groupBox3.Controls.Add(this.button4);
			this.groupBox3.Controls.Add(this.checkBox5);
			this.groupBox3.Controls.Add(this.label2);
			this.groupBox3.Controls.Add(this.label4);
			this.groupBox3.Controls.Add(this.label6);
			this.groupBox3.Controls.Add(this.ChB_showIndexes);
			this.groupBox3.Location = new System.Drawing.Point(200, 8);
			this.groupBox3.Name = "groupBox3";
			this.groupBox3.Size = new System.Drawing.Size(200, 184);
			this.groupBox3.TabIndex = 1;
			this.groupBox3.TabStop = false;
			this.groupBox3.Text = "Graph marks";
			// 
			// BT_FontIndexes
			// 
			this.BT_FontIndexes.Location = new System.Drawing.Point(120, 150);
			this.BT_FontIndexes.Name = "BT_FontIndexes";
			this.BT_FontIndexes.Size = new System.Drawing.Size(48, 23);
			this.BT_FontIndexes.TabIndex = 5;
			this.BT_FontIndexes.Text = "Font...";
			this.BT_FontIndexes.Click += new System.EventHandler(this.BT_FontIndexes_Click);
			// 
			// numericUpDown2
			// 
			this.numericUpDown2.Location = new System.Drawing.Point(120, 56);
			this.numericUpDown2.Minimum = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.numericUpDown2.Name = "numericUpDown2";
			this.numericUpDown2.Size = new System.Drawing.Size(40, 20);
			this.numericUpDown2.TabIndex = 1;
			this.numericUpDown2.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.numericUpDown2.Value = new System.Decimal(new int[] {
																		 1,
																		 0,
																		 0,
																		 0});
			// 
			// numericUpDown4
			// 
			this.numericUpDown4.Location = new System.Drawing.Point(120, 88);
			this.numericUpDown4.Minimum = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.numericUpDown4.Name = "numericUpDown4";
			this.numericUpDown4.Size = new System.Drawing.Size(40, 20);
			this.numericUpDown4.TabIndex = 2;
			this.numericUpDown4.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.numericUpDown4.Value = new System.Decimal(new int[] {
																		 1,
																		 0,
																		 0,
																		 0});
			// 
			// button4
			// 
			this.button4.BackColor = System.Drawing.SystemColors.Control;
			this.button4.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.button4.Location = new System.Drawing.Point(120, 120);
			this.button4.Name = "button4";
			this.button4.Size = new System.Drawing.Size(40, 16);
			this.button4.TabIndex = 3;
			this.button4.Click += new System.EventHandler(this.button4_Click);
			// 
			// checkBox5
			// 
			this.checkBox5.Location = new System.Drawing.Point(16, 24);
			this.checkBox5.Name = "checkBox5";
			this.checkBox5.Size = new System.Drawing.Size(96, 24);
			this.checkBox5.TabIndex = 0;
			this.checkBox5.Text = "Show marks";
			this.checkBox5.CheckedChanged += new System.EventHandler(this.checkBox5_CheckedChanged);
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(32, 56);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(88, 23);
			this.label2.TabIndex = 6;
			this.label2.Text = "Size of marks:";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(32, 88);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(88, 23);
			this.label4.TabIndex = 6;
			this.label4.Text = "Marks line width:";
			// 
			// label6
			// 
			this.label6.Location = new System.Drawing.Point(32, 120);
			this.label6.Name = "label6";
			this.label6.Size = new System.Drawing.Size(88, 24);
			this.label6.TabIndex = 9;
			this.label6.Text = "Marks line color:";
			// 
			// ChB_showIndexes
			// 
			this.ChB_showIndexes.Location = new System.Drawing.Point(16, 153);
			this.ChB_showIndexes.Name = "ChB_showIndexes";
			this.ChB_showIndexes.Size = new System.Drawing.Size(96, 16);
			this.ChB_showIndexes.TabIndex = 4;
			this.ChB_showIndexes.Text = "Show indexes";
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(32, 56);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(96, 23);
			this.label3.TabIndex = 6;
			this.label3.Text = "Graph line width:";
			// 
			// numericUpDown3
			// 
			this.numericUpDown3.Location = new System.Drawing.Point(120, 56);
			this.numericUpDown3.Minimum = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.numericUpDown3.Name = "numericUpDown3";
			this.numericUpDown3.Size = new System.Drawing.Size(40, 20);
			this.numericUpDown3.TabIndex = 1;
			this.numericUpDown3.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.numericUpDown3.Value = new System.Decimal(new int[] {
																		 1,
																		 0,
																		 0,
																		 0});
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(32, 88);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(104, 24);
			this.label5.TabIndex = 9;
			this.label5.Text = "Graph line color:";
			// 
			// button3
			// 
			this.button3.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.button3.Location = new System.Drawing.Point(120, 88);
			this.button3.Name = "button3";
			this.button3.Size = new System.Drawing.Size(40, 16);
			this.button3.TabIndex = 2;
			this.button3.Click += new System.EventHandler(this.button3_Click_1);
			// 
			// groupBox4
			// 
			this.groupBox4.Controls.Add(this.RB_PolyLine);
			this.groupBox4.Controls.Add(this.numericUpDown3);
			this.groupBox4.Controls.Add(this.button3);
			this.groupBox4.Controls.Add(this.label3);
			this.groupBox4.Controls.Add(this.label5);
			this.groupBox4.Controls.Add(this.ChB_showRectangle);
			this.groupBox4.Controls.Add(this.ChB_ShowLine);
			this.groupBox4.Controls.Add(this.RB_Bezier);
			this.groupBox4.Controls.Add(this.label12);
			this.groupBox4.Location = new System.Drawing.Point(8, 8);
			this.groupBox4.Name = "groupBox4";
			this.groupBox4.Size = new System.Drawing.Size(184, 184);
			this.groupBox4.TabIndex = 0;
			this.groupBox4.TabStop = false;
			this.groupBox4.Text = "Graph line";
			// 
			// RB_PolyLine
			// 
			this.RB_PolyLine.Location = new System.Drawing.Point(96, 120);
			this.RB_PolyLine.Name = "RB_PolyLine";
			this.RB_PolyLine.Size = new System.Drawing.Size(72, 16);
			this.RB_PolyLine.TabIndex = 3;
			this.RB_PolyLine.Text = "Polyline";
			// 
			// ChB_showRectangle
			// 
			this.ChB_showRectangle.Location = new System.Drawing.Point(16, 160);
			this.ChB_showRectangle.Name = "ChB_showRectangle";
			this.ChB_showRectangle.Size = new System.Drawing.Size(112, 16);
			this.ChB_showRectangle.TabIndex = 5;
			this.ChB_showRectangle.Text = "Show border line";
			// 
			// ChB_ShowLine
			// 
			this.ChB_ShowLine.Location = new System.Drawing.Point(16, 24);
			this.ChB_ShowLine.Name = "ChB_ShowLine";
			this.ChB_ShowLine.Size = new System.Drawing.Size(96, 24);
			this.ChB_ShowLine.TabIndex = 0;
			this.ChB_ShowLine.Text = "Show line";
			this.ChB_ShowLine.CheckedChanged += new System.EventHandler(this.ChB_ShowLine_CheckedChanged);
			// 
			// RB_Bezier
			// 
			this.RB_Bezier.Location = new System.Drawing.Point(96, 140);
			this.RB_Bezier.Name = "RB_Bezier";
			this.RB_Bezier.Size = new System.Drawing.Size(72, 16);
			this.RB_Bezier.TabIndex = 4;
			this.RB_Bezier.Text = "Bezier";
			// 
			// label12
			// 
			this.label12.Location = new System.Drawing.Point(16, 120);
			this.label12.Name = "label12";
			this.label12.Size = new System.Drawing.Size(72, 16);
			this.label12.TabIndex = 3;
			this.label12.Text = "Interpolation:";
			// 
			// NUD_xSegmentCount
			// 
			this.NUD_xSegmentCount.Location = new System.Drawing.Point(112, 80);
			this.NUD_xSegmentCount.Maximum = new System.Decimal(new int[] {
																			  1000,
																			  0,
																			  0,
																			  0});
			this.NUD_xSegmentCount.Minimum = new System.Decimal(new int[] {
																			  1,
																			  0,
																			  0,
																			  0});
			this.NUD_xSegmentCount.Name = "NUD_xSegmentCount";
			this.NUD_xSegmentCount.Size = new System.Drawing.Size(48, 20);
			this.NUD_xSegmentCount.TabIndex = 2;
			this.NUD_xSegmentCount.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.NUD_xSegmentCount.Value = new System.Decimal(new int[] {
																			1,
																			0,
																			0,
																			0});
			// 
			// groupBox5
			// 
			this.groupBox5.Controls.Add(this.label7);
			this.groupBox5.Controls.Add(this.NUD_xSegmentCount);
			this.groupBox5.Controls.Add(this.checkBox3);
			this.groupBox5.Controls.Add(this.checkBox1);
			this.groupBox5.Controls.Add(this.NUD_decPlaceCountX);
			this.groupBox5.Controls.Add(this.label1);
			this.groupBox5.Location = new System.Drawing.Point(8, 8);
			this.groupBox5.Name = "groupBox5";
			this.groupBox5.Size = new System.Drawing.Size(192, 152);
			this.groupBox5.TabIndex = 0;
			this.groupBox5.TabStop = false;
			this.groupBox5.Text = "x-axis";
			// 
			// label7
			// 
			this.label7.Location = new System.Drawing.Point(16, 80);
			this.label7.Name = "label7";
			this.label7.Size = new System.Drawing.Size(84, 16);
			this.label7.TabIndex = 6;
			this.label7.Text = "Segment count:";
			// 
			// NUD_decPlaceCountX
			// 
			this.NUD_decPlaceCountX.Location = new System.Drawing.Point(112, 112);
			this.NUD_decPlaceCountX.Maximum = new System.Decimal(new int[] {
																			   9,
																			   0,
																			   0,
																			   0});
			this.NUD_decPlaceCountX.Name = "NUD_decPlaceCountX";
			this.NUD_decPlaceCountX.Size = new System.Drawing.Size(48, 20);
			this.NUD_decPlaceCountX.TabIndex = 3;
			this.NUD_decPlaceCountX.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.NUD_decPlaceCountX.Value = new System.Decimal(new int[] {
																			 1,
																			 0,
																			 0,
																			 0});
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(16, 112);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(112, 16);
			this.label1.TabIndex = 6;
			this.label1.Text = "Dec. place count:";
			// 
			// groupBox6
			// 
			this.groupBox6.Controls.Add(this.checkBox4);
			this.groupBox6.Controls.Add(this.checkBox2);
			this.groupBox6.Controls.Add(this.numericUpDown1);
			this.groupBox6.Controls.Add(this.label8);
			this.groupBox6.Controls.Add(this.NUD_decPlaceCountY);
			this.groupBox6.Controls.Add(this.label9);
			this.groupBox6.Location = new System.Drawing.Point(208, 8);
			this.groupBox6.Name = "groupBox6";
			this.groupBox6.Size = new System.Drawing.Size(192, 152);
			this.groupBox6.TabIndex = 1;
			this.groupBox6.TabStop = false;
			this.groupBox6.Text = "y-axis";
			// 
			// label8
			// 
			this.label8.Location = new System.Drawing.Point(16, 80);
			this.label8.Name = "label8";
			this.label8.Size = new System.Drawing.Size(88, 16);
			this.label8.TabIndex = 6;
			this.label8.Text = "Segment count:";
			// 
			// NUD_decPlaceCountY
			// 
			this.NUD_decPlaceCountY.Location = new System.Drawing.Point(112, 112);
			this.NUD_decPlaceCountY.Maximum = new System.Decimal(new int[] {
																			   9,
																			   0,
																			   0,
																			   0});
			this.NUD_decPlaceCountY.Name = "NUD_decPlaceCountY";
			this.NUD_decPlaceCountY.Size = new System.Drawing.Size(48, 20);
			this.NUD_decPlaceCountY.TabIndex = 3;
			this.NUD_decPlaceCountY.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.NUD_decPlaceCountY.Value = new System.Decimal(new int[] {
																			 1,
																			 0,
																			 0,
																			 0});
			// 
			// label9
			// 
			this.label9.Location = new System.Drawing.Point(16, 112);
			this.label9.Name = "label9";
			this.label9.Size = new System.Drawing.Size(112, 16);
			this.label9.TabIndex = 6;
			this.label9.Text = "Dec. place count:";
			// 
			// Bt_apply
			// 
			this.Bt_apply.Location = new System.Drawing.Point(304, 248);
			this.Bt_apply.Name = "Bt_apply";
			this.Bt_apply.Size = new System.Drawing.Size(56, 23);
			this.Bt_apply.TabIndex = 2;
			this.Bt_apply.Text = "&Apply";
			this.Bt_apply.Click += new System.EventHandler(this.Bt_apply_Click);
			// 
			// Bt_font
			// 
			this.Bt_font.Location = new System.Drawing.Point(340, 171);
			this.Bt_font.Name = "Bt_font";
			this.Bt_font.Size = new System.Drawing.Size(53, 24);
			this.Bt_font.TabIndex = 4;
			this.Bt_font.Text = "Font...";
			this.Bt_font.Click += new System.EventHandler(this.Bt_font_Click);
			// 
			// tabControl1
			// 
			this.tabControl1.Controls.Add(this.tabPage1);
			this.tabControl1.Controls.Add(this.tabPage2);
			this.tabControl1.Controls.Add(this.tabPage3);
			this.tabControl1.Location = new System.Drawing.Point(8, 8);
			this.tabControl1.Name = "tabControl1";
			this.tabControl1.SelectedIndex = 0;
			this.tabControl1.Size = new System.Drawing.Size(416, 232);
			this.tabControl1.TabIndex = 0;
			// 
			// tabPage1
			// 
			this.tabPage1.Controls.Add(this.groupBox5);
			this.tabPage1.Controls.Add(this.groupBox6);
			this.tabPage1.Controls.Add(this.Bt_font);
			this.tabPage1.Controls.Add(this.BT_AxesLineColor);
			this.tabPage1.Controls.Add(this.label10);
			this.tabPage1.Controls.Add(this.BT_AxesTextColor);
			this.tabPage1.Controls.Add(this.label11);
			this.tabPage1.Location = new System.Drawing.Point(4, 22);
			this.tabPage1.Name = "tabPage1";
			this.tabPage1.Size = new System.Drawing.Size(408, 206);
			this.tabPage1.TabIndex = 0;
			this.tabPage1.Text = "Axes";
			// 
			// BT_AxesLineColor
			// 
			this.BT_AxesLineColor.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.BT_AxesLineColor.Location = new System.Drawing.Point(74, 176);
			this.BT_AxesLineColor.Name = "BT_AxesLineColor";
			this.BT_AxesLineColor.Size = new System.Drawing.Size(40, 16);
			this.BT_AxesLineColor.TabIndex = 2;
			this.BT_AxesLineColor.Click += new System.EventHandler(this.BT_AxesLineColor_Click);
			// 
			// label10
			// 
			this.label10.Location = new System.Drawing.Point(16, 176);
			this.label10.Name = "label10";
			this.label10.Size = new System.Drawing.Size(56, 16);
			this.label10.TabIndex = 0;
			this.label10.Text = "Line color:";
			// 
			// BT_AxesTextColor
			// 
			this.BT_AxesTextColor.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.BT_AxesTextColor.Location = new System.Drawing.Point(239, 176);
			this.BT_AxesTextColor.Name = "BT_AxesTextColor";
			this.BT_AxesTextColor.Size = new System.Drawing.Size(40, 16);
			this.BT_AxesTextColor.TabIndex = 3;
			this.BT_AxesTextColor.Click += new System.EventHandler(this.BT_AxesTextColor_Click);
			// 
			// label11
			// 
			this.label11.Location = new System.Drawing.Point(167, 176);
			this.label11.Name = "label11";
			this.label11.Size = new System.Drawing.Size(72, 16);
			this.label11.TabIndex = 6;
			this.label11.Text = "Labels color:";
			// 
			// tabPage2
			// 
			this.tabPage2.Controls.Add(this.groupBox4);
			this.tabPage2.Controls.Add(this.groupBox3);
			this.tabPage2.Location = new System.Drawing.Point(4, 22);
			this.tabPage2.Name = "tabPage2";
			this.tabPage2.Size = new System.Drawing.Size(408, 206);
			this.tabPage2.TabIndex = 1;
			this.tabPage2.Text = "Graph";
			// 
			// tabPage3
			// 
			this.tabPage3.Controls.Add(this.groupBox1);
			this.tabPage3.Location = new System.Drawing.Point(4, 22);
			this.tabPage3.Name = "tabPage3";
			this.tabPage3.Size = new System.Drawing.Size(408, 206);
			this.tabPage3.TabIndex = 2;
			this.tabPage3.Text = "Data view";
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.Bt_HMarksFont);
			this.groupBox1.Controls.Add(this.NUD_sizeHMarks);
			this.groupBox1.Controls.Add(this.NUD_sizeHMarksLineWidth);
			this.groupBox1.Controls.Add(this.Bt_HMarksColor);
			this.groupBox1.Controls.Add(this.label13);
			this.groupBox1.Controls.Add(this.label14);
			this.groupBox1.Controls.Add(this.label15);
			this.groupBox1.Controls.Add(this.Chb_allowHighligting);
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(392, 184);
			this.groupBox1.TabIndex = 1;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Selected point highligting";
			// 
			// Chb_allowHighligting
			// 
			this.Chb_allowHighligting.Location = new System.Drawing.Point(16, 26);
			this.Chb_allowHighligting.Name = "Chb_allowHighligting";
			this.Chb_allowHighligting.Size = new System.Drawing.Size(112, 21);
			this.Chb_allowHighligting.TabIndex = 0;
			this.Chb_allowHighligting.Text = "Allow highligting";
			this.Chb_allowHighligting.CheckedChanged += new System.EventHandler(this.Chb_allowHighligting_CheckedChanged);
			// 
			// Bt_restoreDefault
			// 
			this.Bt_restoreDefault.Location = new System.Drawing.Point(9, 248);
			this.Bt_restoreDefault.Name = "Bt_restoreDefault";
			this.Bt_restoreDefault.Size = new System.Drawing.Size(96, 23);
			this.Bt_restoreDefault.TabIndex = 0;
			this.Bt_restoreDefault.Text = "&Default settings";
			this.Bt_restoreDefault.Click += new System.EventHandler(this.Bt_restoreDefault_Click);
			// 
			// NUD_sizeHMarks
			// 
			this.NUD_sizeHMarks.Location = new System.Drawing.Point(176, 56);
			this.NUD_sizeHMarks.Minimum = new System.Decimal(new int[] {
																		   1,
																		   0,
																		   0,
																		   0});
			this.NUD_sizeHMarks.Name = "NUD_sizeHMarks";
			this.NUD_sizeHMarks.Size = new System.Drawing.Size(40, 20);
			this.NUD_sizeHMarks.TabIndex = 1;
			this.NUD_sizeHMarks.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.NUD_sizeHMarks.Value = new System.Decimal(new int[] {
																		 1,
																		 0,
																		 0,
																		 0});
			// 
			// NUD_sizeHMarksLineWidth
			// 
			this.NUD_sizeHMarksLineWidth.Location = new System.Drawing.Point(176, 88);
			this.NUD_sizeHMarksLineWidth.Minimum = new System.Decimal(new int[] {
																					1,
																					0,
																					0,
																					0});
			this.NUD_sizeHMarksLineWidth.Name = "NUD_sizeHMarksLineWidth";
			this.NUD_sizeHMarksLineWidth.Size = new System.Drawing.Size(40, 20);
			this.NUD_sizeHMarksLineWidth.TabIndex = 2;
			this.NUD_sizeHMarksLineWidth.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
			this.NUD_sizeHMarksLineWidth.Value = new System.Decimal(new int[] {
																				  1,
																				  0,
																				  0,
																				  0});
			// 
			// Bt_HMarksColor
			// 
			this.Bt_HMarksColor.BackColor = System.Drawing.SystemColors.Control;
			this.Bt_HMarksColor.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.Bt_HMarksColor.Location = new System.Drawing.Point(176, 120);
			this.Bt_HMarksColor.Name = "Bt_HMarksColor";
			this.Bt_HMarksColor.Size = new System.Drawing.Size(40, 16);
			this.Bt_HMarksColor.TabIndex = 3;
			this.Bt_HMarksColor.Click += new System.EventHandler(this.Bt_HMarksColor_Click);
			// 
			// label13
			// 
			this.label13.Location = new System.Drawing.Point(32, 56);
			this.label13.Name = "label13";
			this.label13.Size = new System.Drawing.Size(136, 23);
			this.label13.TabIndex = 15;
			this.label13.Text = "Size of highlighted marks:";
			// 
			// label14
			// 
			this.label14.Location = new System.Drawing.Point(32, 88);
			this.label14.Name = "label14";
			this.label14.Size = new System.Drawing.Size(152, 23);
			this.label14.TabIndex = 14;
			this.label14.Text = "Highlighted marks line width:";
			// 
			// label15
			// 
			this.label15.Location = new System.Drawing.Point(32, 120);
			this.label15.Name = "label15";
			this.label15.Size = new System.Drawing.Size(152, 24);
			this.label15.TabIndex = 16;
			this.label15.Text = "Highlighted marks line color:";
			// 
			// Bt_HMarksFont
			// 
			this.Bt_HMarksFont.Location = new System.Drawing.Point(32, 144);
			this.Bt_HMarksFont.Name = "Bt_HMarksFont";
			this.Bt_HMarksFont.Size = new System.Drawing.Size(53, 23);
			this.Bt_HMarksFont.TabIndex = 4;
			this.Bt_HMarksFont.Text = "Font...";
			this.Bt_HMarksFont.Click += new System.EventHandler(this.Bt_HMarksFont_Click);
			// 
			// CurveRendererSettings
			// 
			this.AcceptButton = this.button1;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.button2;
			this.ClientSize = new System.Drawing.Size(434, 280);
			this.Controls.Add(this.tabControl1);
			this.Controls.Add(this.button2);
			this.Controls.Add(this.button1);
			this.Controls.Add(this.Bt_apply);
			this.Controls.Add(this.Bt_restoreDefault);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "CurveRendererSettings";
			this.Text = "Curve Graph Settings";
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown1)).EndInit();
			this.groupBox3.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown2)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown4)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numericUpDown3)).EndInit();
			this.groupBox4.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.NUD_xSegmentCount)).EndInit();
			this.groupBox5.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.NUD_decPlaceCountX)).EndInit();
			this.groupBox6.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.NUD_decPlaceCountY)).EndInit();
			this.tabControl1.ResumeLayout(false);
			this.tabPage1.ResumeLayout(false);
			this.tabPage2.ResumeLayout(false);
			this.tabPage3.ResumeLayout(false);
			this.groupBox1.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.NUD_sizeHMarks)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.NUD_sizeHMarksLineWidth)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion


		#region Event handling

		/// <summary>
		/// Save settings (button OK click).
		/// </summary>
		private void button1_Click(object sender, System.EventArgs e)
		{
			this.ApplyChanges();
			this.Close();
		} // button1_Click()

		/// <summary>
		/// Button Storno click.
		/// </summary>
		private void button2_Click(object sender, System.EventArgs e)
		{
			this.DiscardChanges();
			this.Close();
			this.renderer.panel.Refresh();
		} // button2_Click()

		/// <summary>
		/// Button Apply click.
		/// </summary>
		private void Bt_apply_Click(object sender, System.EventArgs e)
		{
			this.ApplyChanges();
		} // Bt_apply_Click()

		/// <summary>
		/// Changed the state of checkbox for marker size.
		/// </summary>
		private void checkBox5_CheckedChanged(object sender, System.EventArgs e)
		{
			this.SetAccessabilityMarks();
		} // checkBox5_CheckedChanged()

		/// <summary>
		/// Change the color of graph.
		/// </summary>
		private void button3_Click_1(object sender, System.EventArgs e)
		{
			this.colorDialog1.ShowDialog(this);
			this.button3.BackColor = this.colorDialog1.Color;
			this.ApplyChanges();
		} // button3_Click_1()

		/// <summary>
		/// Change the color of markers.
		/// </summary>
		private void button4_Click(object sender, System.EventArgs e)
		{
			this.colorDialog2.ShowDialog(this);
			this.button4.BackColor = this.colorDialog2.Color;
			this.ApplyChanges();
		}

		/// <summary>
		///  Button change axesFont clicked.
		/// </summary>
		private void Bt_font_Click(object sender, System.EventArgs e)
		{
			this.FD_Axes.ShowDialog(this);
			this.ApplyChanges();
		}

		/// <summary>
		/// Button axesColor clicked.
		/// </summary>
		private void BT_AxesLineColor_Click(object sender, System.EventArgs e)
		{
			this.CD_AxesLine.ShowDialog(this);
			this.BT_AxesLineColor.BackColor = this.CD_AxesLine.Color;
			this.ApplyChanges();
		}

		/// <summary>
		/// Button axesTextColor clicked.
		/// </summary>
		private void BT_AxesTextColor_Click(object sender, System.EventArgs e)
		{
			this.CD_AxesText.ShowDialog(this);
			this.BT_AxesTextColor.BackColor = this.CD_AxesText.Color;
			this.ApplyChanges();
		}

		/// <summary>
		/// Button indexesFont clicked.
		/// </summary>
		private void BT_FontIndexes_Click(object sender, System.EventArgs e)
		{
			this.FD_Indexes.ShowDialog(this);
			this.ApplyChanges();
		}

		/// <summary>
		/// Button hMarksColor clicked.
		/// </summary>
		private void Bt_HMarksColor_Click(object sender, System.EventArgs e)
		{
			this.CD_hMarks.ShowDialog(this);
			this.Bt_HMarksColor.BackColor = this.CD_hMarks.Color;
			this.ApplyChanges();
		}

		/// <summary>
		/// Button hMarksFont clicked.
		/// </summary>
		private void Bt_HMarksFont_Click(object sender, System.EventArgs e)
		{
			this.FD_hMarks.ShowDialog(this);
			this.ApplyChanges();
		}

		/// <summary>
		/// Changed state of checkBox 'ShowLine'.
		/// </summary>
		private void ChB_ShowLine_CheckedChanged(object sender, System.EventArgs e)
		{
			this.SetAccessabilityLine();
		}

		/// <summary>
		/// Changed state of checkBox 'AllowHighlighting'
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void Chb_allowHighligting_CheckedChanged(object sender, System.EventArgs e)
		{
			this.SetAccessabilityHighlighting();
		}

		/// <summary>
		/// Set accessability of controls for graph marks settings.
		/// (depending on checkBox5)
		/// </summary>
		private void SetAccessabilityMarks()
		{
			this.numericUpDown2.Enabled = this.checkBox5.Checked;
			this.numericUpDown4.Enabled = this.checkBox5.Checked;
			this.button4.Enabled = this.checkBox5.Checked;
			this.label2.Enabled = this.checkBox5.Checked;
			this.label4.Enabled = this.checkBox5.Checked;
			this.label6.Enabled = this.checkBox5.Checked;
			this.ChB_showIndexes.Enabled = this.checkBox5.Checked;
			this.BT_FontIndexes.Enabled = this.checkBox5.Checked;
		}

		/// <summary>
		/// Set accessability of controls for graph line settings.
		/// (depending on checkBox_ShowLine)
		/// </summary>
		private void SetAccessabilityLine()
		{
			this.numericUpDown3.Enabled = this.ChB_ShowLine.Checked;
			this.button3.Enabled = this.ChB_ShowLine.Checked;
			this.RB_PolyLine.Enabled = this.ChB_ShowLine.Checked;
			this.RB_Bezier.Enabled = this.ChB_ShowLine.Checked;
		}

		/// <summary>
		/// Set accessability of controls for graph highlighting settings.
		/// (depending on checkBox_allowHighlighting)
		/// </summary>
		private void SetAccessabilityHighlighting()
		{
			this.NUD_sizeHMarks.Enabled = this.Chb_allowHighligting.Checked;
			this.NUD_sizeHMarksLineWidth.Enabled = this.Chb_allowHighligting.Checked;
			this.Bt_HMarksColor.Enabled = this.Chb_allowHighligting.Checked;
			this.Bt_HMarksFont.Enabled = this.Chb_allowHighligting.Checked;
		}

		/// <summary>
		/// Restore default settings.
		/// </summary>
		private void Bt_restoreDefault_Click(object sender, System.EventArgs e)
		{
			this.NUD_xSegmentCount.Value  = CurveRenderer.def_x_segment_count;
			this.numericUpDown1.Value     = CurveRenderer.def_y_segment_count;
			this.checkBox1.Checked        = CurveRenderer.def_showXGrid;
			this.checkBox2.Checked        = CurveRenderer.def_showYGrid;
			this.checkBox3.Checked        = CurveRenderer.def_showXAxesLegend;
			this.checkBox4.Checked        = CurveRenderer.def_showYAxesLegend;
			this.NUD_decPlaceCountX.Value = CurveRenderer.def_decPlaceCountX;
			this.NUD_decPlaceCountY.Value = CurveRenderer.def_decPlaceCountY;
			this.checkBox5.Checked        = CurveRenderer.def_showGraphMarks;
			this.ChB_ShowLine.Checked     = CurveRenderer.def_showGraphLine;
			this.numericUpDown3.Value     = CurveRenderer.def_graphLineWidth;
			this.numericUpDown4.Value     = CurveRenderer.def_graphMarkLineWidth;
			this.numericUpDown2.Value     = CurveRenderer.def_graph_mark_size;
			this.ChB_showRectangle.Checked = CurveRenderer.def_showRectangle;
			this.ChB_showIndexes.Checked = CurveRenderer.def_showIndexes;

			if (CurveRenderer.def_interpolation == CurveRenderer.Interpolation.PolyLine)
				this.RB_PolyLine.Checked = true;
			else
				this.RB_Bezier.Checked = true;

			this.colorDialog1.Color = renderer.def_graphLineColor;
			this.button3.BackColor = this.colorDialog1.Color;

			this.colorDialog2.Color = renderer.def_marksLineColor;
			this.button4.BackColor = this.colorDialog2.Color;

			this.CD_AxesLine.Color = renderer.def_axesLineColor;
			this.BT_AxesLineColor.BackColor = this.CD_AxesLine.Color;

			this.CD_AxesText.Color = renderer.def_axesTextColor;
			this.BT_AxesTextColor.BackColor = this.CD_AxesText.Color;

			this.FD_Axes.Font = renderer.def_axisFont;
			this.FD_Indexes.Font = renderer.def_indexFont;

			this.Chb_allowHighligting.Checked = CurveRenderer.def_allowHighlighting;
			this.NUD_sizeHMarks.Value = CurveRenderer.def_hMarksSize;
			this.NUD_sizeHMarksLineWidth.Value = CurveRenderer.def_hMarksLineWidth;

			this.CD_hMarks.Color = renderer.def_hMarksColor;
			this.Bt_HMarksColor.BackColor = this.CD_hMarks.Color;
			this.FD_hMarks.Font = renderer.def_hMarksFont;

			this.SetAccessabilityMarks();
			this.SetAccessabilityLine();		
			this.SetAccessabilityHighlighting();
		}

		#endregion


	} // class CurveRendererSettings
} // namespace
