using System;
using System.Collections.Generic;
using System.Text;
using Zcu.Mve.Core;
using Zcu.Mve.Visualization;
using System.ComponentModel;

namespace Zcu.Mve.Visualization
{	
	[ModuleInfo("Libor Va", "A source module for RegGridND. Grid's dimension, position and resolution can be controlled using the Mins, Maxs and Sizes properties.")]
	[PortInfo("RegGridND", "Resulting RegGridND.")]
	/// <summary>
	/// A source module for RegGridND. Grid's dimension, position and resolution can be controlled using the Mins, Maxs and Sizes properties.
	/// </summary>
    class RegGridNDSource: Module
    {
		/// <summary>
		/// default constructor, adds the output port.
		/// </summary>
        public RegGridNDSource()
        {
            AddOutPort("RegGridND", typeof(RegGridND));
        }

        private string mins = "0, 0, 0";
		private string maxs = "1, 1, 1";
		private string sizes = "64, 64, 64";

		private bool paramsChanged = true;

		private RegGridND result = null;

		/// <summary>
		/// Minima in each dimension, separated by a comma
		/// </summary>
		[Description("Minima in each dimension, separated by a comma")]
        public string Mins
        {
            get { return (mins); }
            set
            {
                if (value != "")
                {
                    mins = value;
                    paramsChanged = true;
                }
                else
                {
                    throw new MveException(this, "Mins cannot be an empty string");
                }
            }
        }

		/// <summary>
		/// Maxima in each dimension, separated by a comma
		/// </summary>
		[Description("Maxima in each dimension, separated by a comma")]
        public string Maxs
        {
            get { return (maxs); }
            set
            {
                if (value != "")
                {
                    maxs = value;
                    paramsChanged = true;
                }
                else
                {
                    throw new MveException(this, "Maxs cannot be an empty string");
                }
            }
        }

		/// <summary>
		/// Resolutions in each dimension, separated by a comma
		/// </summary>
		[Description("Resolutions in each dimension, separated by a comma")]
        public string Sizes
        {
            get { return (sizes); }
            set
            {
                if (value != "")
                {
                    sizes = value;
                    paramsChanged = true;
                }
                else
                {
                    throw new MveException(this, "Sizes cannot be an empty string");
                }
            }
        }

		/// <summary>
		/// Parses the property values and generates the resulting grid.
		/// </summary>
        public override void Execute()
        {
            if (paramsChanged || (result == null))
            {
                string[] parts = sizes.Split(new char[] { ',' });
                int[] sizeVals = new int[parts.Length];
                for (int i = 0; i < parts.Length; i++)
                {
                    sizeVals[i] = int.Parse(parts[i]);
                }

                parts = mins.Split(new char[] { ',' });
                if (parts.Length != sizeVals.Length)
                {
                    throw new MveException(this, "Number of minimums is different from number of sizes");
                }
                double[] minVals = new double[parts.Length];
                for (int i = 0; i < parts.Length; i++)
                {
                    minVals[i] = double.Parse(parts[i]);
                }

                parts = maxs.Split(new char[] { ',' });
                if (parts.Length != sizeVals.Length)
                {
                    throw new MveException(this, "Number of maximums is different from number of sizes");
                }
                double[] maxVals = new double[parts.Length];
                for (int i = 0; i < parts.Length; i++)
                {
                    maxVals[i] = double.Parse(parts[i]);
                }

                result = new RegGridND(minVals, maxVals, sizeVals);
                SetOutput("RegGridND", result);
                paramsChanged = false;
            }
            else
            {
                SetOutput("RegGridND", result, true);
            }
        }
    }
}
