using System;
using System.Globalization;
using Zcu.Mve.Core;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Class represent a texture coordinate.
	/// </summary>
	public struct TextureCoord : IAttribute
	{
		/// <summary>
		/// Line index in texture image.
		/// </summary>
		public float U;

		/// <summary>
		/// Column index in texture image.
		/// </summary>
		public float V;

		/// <summary>
		/// ID of related texture.
		/// </summary>
		public int TextureID;

		/// <summary>
		/// Creates a TextureCoord object.
		/// </summary>
		/// <param name="u">Line index in texture image.</param>
		/// <param name="v">Column index in texture image.</param>
		/// <param name="TextureID">ID of related texture.</param>
		public TextureCoord(float u, float v, int TextureID)
		{
			this.U = u;
			this.V = v;
			this.TextureID = TextureID;
		} // TextureCoord()

		/// <summary>
		/// Read data from Xml file to current structure.
		/// </summary>
		/// <param name="xmlTextReader">Stream to be read.</param>
		public void ReadData(System.Xml.XmlTextReader xmlTextReader)
		{
			NumberFormatInfo nfi = new CultureInfo("en-US", false).NumberFormat;
			string[] stringData = xmlTextReader.ReadString().Trim().Split(' ');
			this.U = Single.Parse(stringData[0], nfi);
			this.V = Single.Parse(stringData[1], nfi);
			this.TextureID = Int32.Parse(stringData[2]);
		} // ReadData()

		/// <summary>
		/// Write current data to Xml file.
		/// </summary>
		/// <param name="xmlTextWriter">Stream to be write.</param>
		public void WriteData(System.Xml.XmlTextWriter xmlTextWriter)
		{
			NumberFormatInfo nfi = new CultureInfo("en-US", false).NumberFormat;
			xmlTextWriter.WriteString(this.U.ToString(nfi) + " " + this.V.ToString(nfi) + " " + this.TextureID);
		} // WriteData()

		/// <summary>
		/// Deep copy of data object and its subelements.
		/// </summary>
		/// <returns>Same data, different memory space.</returns>
		public Zcu.Mve.Core.IDataObject DeepCopy()
		{
			return new TextureCoord(this.U, this.V, this.TextureID);
		} // DeepCopy()

		/// <summary>
		/// Check the consistency of current data structure.
		/// </summary>
		/// <returns>True if structure is consistent.</returns>
		public bool CheckConsistence()
		{
			if ((this.U < 0) || (this.V < 0))
			{
				Console.WriteLine("Error! " + this.GetType().Name + ": index cannot be negative.");
				return false;
			}
			else
				return true;
		} // CheckConsistence()

		/// <summary>
		/// Returns a String that represents the current Object.
		/// </summary>
		/// <returns>String that represents the current Object.</returns>
		override public string ToString()
		{
			return "TextureCoord: U = " + this.U + ", V = " + this.V + ", TextureID = " + this.TextureID;
		} // ToString()

		/// <summary>
		/// Returns array of assembly name.
		/// </summary>
		public string [] LibNames
		{
			get
			{
				return new string [] {Globals.GetLibraryName(this.GetType())};
			}
		}

	} // class TextureCoord
} // namespace
