using System;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Specialization of Mesh. Can contain only Triangle cells.
	/// Attributes are not limited.
	/// </summary>
	public class TriangleMesh : Zcu.Mve.Visualization.Mesh
	{
		/// <summary>
		/// Create empty TriangleMesh. Only Triangle is eigen cell.
		/// </summary>
		public TriangleMesh()
		{
			eigCells.Clear();
			eigCells.Add(typeof(Triangle), null);
		}

		/// <summary>
		/// Returns triangle from array named "Triangle".
		/// </summary>
		/// <param name="index">Index of the triangle.</param>
		/// <returns>Triangle with given index.</returns>
		public Triangle GetTriangle(int index)
		{
			return (Triangle) GetCells("Triangle")[index];
		}

		/// <summary>
		/// Returns number of triangles. (Number of elements in field named "Triangle")
		/// </summary>
		/// <returns>Number of triangles.</returns>
		public int GetNTriangles()
		{
			return GetCells("Triangle").Count;
		}

		/// <summary>
		/// Creates shallow copy of current mesh.
		/// Only array references are coppied.
		/// </summary>
		/// <returns>Shallow copy of current mesh.</returns>
		public override UnstrGrid ShallowCopy()
		{
			TriangleMesh outMesh = new TriangleMesh();
      
			// Shallow copy
			outMesh.Points = this.Points;
			foreach (string cellid in this.GetCellIds())
			{
				outMesh.AddCells(cellid, this.GetCells(cellid));
				foreach (string attrid in this.GetCellAttrsIds(cellid))
				{
					outMesh.AddCellAttrs(cellid, attrid, this.GetCellAttrs(cellid, attrid));
				}
			}
			foreach (string attrid in this.GetPointAttrsIds())
			{
				outMesh.AddPointAttrs(attrid, this.GetPointAttrs(attrid));
			} 

			return outMesh;
		}

	} // class TriangleMesh
} // namespace