using System;
using System.Diagnostics;
using System.Xml;
using System.Collections;
using System.Collections.Generic;
using Zcu.Mve.Core;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// Homogenous one dimensional array of IDataObjects. 
	/// </summary>
	public class UniformDataArray : MveArray
	{
		/// <summary>
		/// For XmlLoader use only. Use parametric construcotr instead.
		/// </summary>
		public UniformDataArray()
		{
		}

		/// <summary>
		/// Creates fixed size, one dimensional array of DataObjects
		/// </summary>
		/// <param name="type">Type of object (only this type is accepted). Must be inherited from Mve.Core.DataObject</param>
		/// <param name="count">Number of array elements</param>
		public UniformDataArray(Type type, int count) : base(type, count)
		{
		}    

		/// <summary>
		/// Number of elements.
		/// </summary>
		public int Count
		{
			get
			{
				return this.Lengths[0];
			}
		}

		/// <summary>
		/// Creates UniformDataArray from ArrayList. 
		/// Elements are not copied. Reference only is passed to the new array.
		/// </summary>
		/// <param name="type">Type of uniform data array.</param>
		/// <param name="list">List to be converted (copied).</param>
		/// <returns>New instance of NonUniformDataArray.</returns>
		public static UniformDataArray FromArrayList(Type type, ArrayList list)
		{
			UniformDataArray ret = new UniformDataArray(type, list.Count);

			for (int i = 0; i < list.Count; i++)
				ret[i] = (IDataObject)list[i];

			return ret;
		}  

        public static UniformDataArray FromList<TDataType>(List<TDataType> l) where TDataType:IDataObject
        {                        
            UniformDataArray ret = new UniformDataArray(typeof(TDataType), l.Count);
            for (int i = 0; i < l.Count; i++)
            {
                ret[i] = l[i];
            }
            return (ret);
        }

        public static UniformDataArray FromDictionaryKeys<TDataType,TValueType>(Dictionary<TDataType, TValueType> l) where TDataType : IDataObject
        {
            UniformDataArray ret = new UniformDataArray(typeof(TDataType), l.Count);
            int i = 0;
            foreach(TDataType e in l.Keys)
            {            
                ret[i] = e;
                i++;
            }
            return (ret);
        }
        /*
            /// <summary>
            /// Deep copy of data object and its subelements.
            /// </summary>
            /// <returns>same data, different memmory space.</returns>
            public override IDataObject DeepCopy()
            {
              UniformDataArray mveArray = new UniformDataArray(this.ElemType, lengths);
              mveArray.array = (Array) this.array.Clone();
      
              // Elements are DataObjects ... lets make deep copy.
              if (typeof(Zcu.Mve.Core.DataObject).IsInstanceOfType(this.ElemType))
              {
                CloneDimension(mveArray.array, this.Rank, new int [this.Rank]);
              }

              return mveArray;
            }
         */
    }
}
