using System;
using System.Text;
using Zcu.Mve.Core;
using Zcu.Mve.Visualization;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// A module that transforms and UnstrGrid or its descendant. Each point is transformed using given transformation matrix.
	/// </summary>
	[ModuleInfo("Libor Va", "A module that transforms and UnstrGrid or its descendant. Each point is transformed using given transformation matrix.")]
	[PortInfo("Data", "UnstrGrid to be transformed. When link is attached to this port a new output port is created with the same type as the input data.")]
	[PortInfo("Transform", "Transform matrix used to transform geometry of the input.")]
    class UnstrGridTransform:Module
    {
        private UnstrGrid output;

		/// <summary>
		/// Default constructor. Only adds input ports, outpu port is added in runtime when link is connected to the Data input port.
		/// </summary>
        public UnstrGridTransform()
        {
            AddInPort("Data", typeof(UnstrGrid));
            AddInPort("Transform", typeof(Transform3D));

            this.OnConnectEvent += new ConnectCallBack(UnstrGridTransform_OnConnectEvent);
            this.OnDisconnectEvent += new DisconnectCallBack(UnstrGridTransform_OnDisconnectEvent);
        }

        void UnstrGridTransform_OnDisconnectEvent(object source, InPort portTo, out bool allowed)
        {
            if (portTo.Name == "Data")
            {
                RemoveOutPort("Output");
            }
            allowed = true;
        }

        void UnstrGridTransform_OnConnectEvent(object source, OutPort portFrom, InPort portTo, out bool allowed)
        {
            if (portTo.Name == "Data")
            {
                AddOutPort("Output", portFrom.PortType);
            }
            allowed = true;
        }

		/// <summary>
		/// performs the transformation of the input data. If no inputs were changed since the last run, then the last result is returned immediately.
		/// </summary>
        public override void Execute()
        {
            if (!IsAllDataSame() || (output == null))
            {
                UnstrGrid input = (UnstrGrid)GetInput("Data");
                Transform3D transform = (Transform3D)GetInput("Transform");

                output = input.ShallowCopy();

                output.Points = new UniformDataArray(input.Points.ElemType, input.Points.Count);

                for (int i = 0; i < output.Points.Count; i++)
                {
                    output.Points[i] = transform.Transform((Point3D)input.Points[i]);
                }

                SetOutput("Output", output);
            }
            else
            {
                SetOutput("Output", output, true);
            }
        }
    }
}
