using System;
using Zcu.Mve.Core;
using System.Collections;
using System.Globalization;

namespace Zcu.Mve.Visualization
{
	/// <summary>
	/// This structure represents Vertex neighbors.
	/// </summary>
	public struct VertexNeighbor : INeighbor
	{		
		/// <summary>
		/// Indices to three neighboring vertices.
		/// </summary>
		public int [] Neighbours;

		/// <summary>
		/// Number of neighbors.
		/// </summary>
		public int Count;

		/// <summary>
		/// Read data from Xml file to current structure.
		/// </summary>
		/// <param name="xmlTextReader">Stream to be read.</param>
		public void ReadData(System.Xml.XmlTextReader xmlTextReader)
		{
			NumberFormatInfo nfi = new CultureInfo("en-US", false).NumberFormat;
			string[] split = xmlTextReader.ReadString().Trim().Split(' ');
			this.Neighbours = new int [split.Length];
			for(int i = 0; i < split.Length; i++) 
				this.Neighbours[i] = Int32.Parse(split[i], nfi);
		} // ReadData()

		/// <summary>
		/// Write current data to Xml file.
		/// </summary>
		/// <param name="xmlTextWriter">Stream to be write.</param>
		public void WriteData(System.Xml.XmlTextWriter xmlTextWriter)
		{
			NumberFormatInfo nfi = new CultureInfo("en-US", false).NumberFormat;
			string s = "";
			for(int i=0; i<this.Neighbours.Length; i++) 
				s += this.Neighbours[i] + " ";

			xmlTextWriter.WriteString(s);
		} // WriteData()

		/// <summary>
		/// Deep copy of data object and its subelements.
		/// </summary>
		/// <returns>Same data, different memory space.</returns>
		public IDataObject DeepCopy()
		{
			VertexNeighbor n = new VertexNeighbor();
			for(int i = 0; i < this.Neighbours.Length; i++) 
				n.Neighbours[i] = this.Neighbours[i];
			return n;
		} // DeepCopy()

		/// <summary>
		/// Returns a String that represents the current Object.
		/// </summary>
		/// <returns>String that represents the current Object.</returns>
		public override string ToString()
		{
			string s = "";
			for(int i=0; i<this.Neighbours.Length; i++) 
				s += this.Neighbours[i] + "; ";
			return "VertexNeighbors: [" + s.Substring(s.Length-2,2) + "]";
		} // ToString()

		/// <summary>
		/// Check the consistency of current data structure.
		/// </summary>
		/// <returns>True if structure is consistent.</returns>
		public bool CheckConsistence()
		{
			return true;
		} // CheckConsistence()

		/// <summary>
		/// Returns array of assembly name.
		/// </summary>
		public string [] LibNames
		{
			get
			{
				return new string [] {Globals.GetLibraryName(this.GetType())};
			}
		}

	} // VertexNeighbor
} // namespace
